import os
import connexion
from jinja2 import Environment, FileSystemLoader
import tempfile
from flask_testing import TestCase
from webservice_fdsn.app.core import constants
from webservice_fdsn.app.utils import pf_helper


def create_openapi_spec(file_handle, template_path, version):
    """Populate swagger jinja vars with values from pf file.
    
    :param str file_handle: Handle to file to dump rendered template to
    :param str template_path: template folder
    :param str version: Spec version to use from template folder

    :rtype: None
    """

    env = Environment(loader=FileSystemLoader(template_path),
                      trim_blocks=True, lstrip_blocks=True)
    # Newer spec versions can be easily supported by creating a new jinja templates
    # for specific FDSN spec version, and using it here.
    template = env.get_template(f'fdsn_spec_{version}.j2')    

    # Render the template using app config values from pf file
    rendered = template.render(pf_helper.get_app_configuration_options())
    file_handle.write(rendered)


class BaseApiTestCase(TestCase):

    def create_app(self):
    	spec_dir = os.path.join(os.path.dirname(__file__),
                                os.pardir, os.pardir, 'openapi')
    	app = connexion.App(__name__, specification_dir=spec_dir)
    	with tempfile.NamedTemporaryFile(mode='w',
                                         delete=True, suffix='.yaml') as spec_file:
	        create_openapi_spec(spec_file, template_path=spec_dir,
	                            version=constants.common_constants.FDSN_SPEC_VERSION)
	        app.add_api(spec_file.name, strict_validation=True)
        	return app.app
