#   Copyright (c) 2021 Boulder Real Time Technologies, Inc.
#
#   This software module is wholly owned by Boulder Real Time
#   Technologies, Inc. Any use of this software module without
#   express written permission from Boulder Real Time Technologies,
#   Inc. is prohibited.
#
#   Author: Ambli LLC (ambli.ll.company@gmail.com)

import os
from http import HTTPStatus

from webservice_fdsn.tests.api import BaseApiTestCase
from webservice_fdsn.app.core.constants import common


class TestEventApi(BaseApiTestCase):

    def setUp(self):
        self.baseurl = '/fdsnws/event/1'

    def test_get_version(self):
        resp = self.client.open(f'{self.baseurl}/version', method='GET')
        self.assertEqual(resp.status_code, HTTPStatus.OK)

    def test_get_catalog(self):
        resp = self.client.open(f'{self.baseurl}/catalogs', method='GET')
        self.assertEqual(resp.status_code, HTTPStatus.OK)

    def test_get_contributors(self):
        resp = self.client.open(f'{self.baseurl}/contributors', method='GET')
        self.assertEqual(resp.status_code, HTTPStatus.OK)

    def test_get_application_wadl(self):
        resp = self.client.open(f'{self.baseurl}/application.wadl', method='GET')
        self.assertEqual(resp.status_code, HTTPStatus.OK)

    """
    # Too much data, and actual data not committed to source control ~200MB), so can't
    # be run anywhere but my dev machine.
    def test_query_ok_dbcentral(self):
        #Test event query on dbcluster schema db
        os.environ[common.ENV_VAR_PF_PATH] = os.path.join(os.path.dirname(__file__), os.pardir,
                                                          'test_data', 'webservice_fdsn.pf')
        # This query returns evids as a list in quakeml
        url = f'{self.baseurl}/query?mindepth=0.1&maxdepth=1000000&minmagnitude=1&maxmagnitude=9'\
              '&limit=2&orderby=time&minlatitude=-90&maxlatitude=90&'\
              'minlongitude=-180&maxlongitude=180&nodata=404&starttime=123.4'
        resp = self.client.open(url, method='GET')
        self.assertEqual(resp.status_code, HTTPStatus.OK)
        # This query returns single evid as an OrderedDict in quakeml
        url = f'{self.baseurl}/query?mindepth=0.1&maxdepth=1000000&minmagnitude=4&maxmagnitude=9'\
              '&limit=2&orderby=time&minlatitude=-90&maxlatitude=90&'\
              'minlongitude=-180&maxlongitude=180&nodata=404&starttime=123.4'
        resp = self.client.open(url, method='GET')
        self.assertEqual(resp.status_code, HTTPStatus.OK)

        os.environ.pop(common.ENV_VAR_PF_PATH)
    """

    def test_query_ok_css(self):
        """Test event query on regular css3.0 db"""
        # This query returns evids as a list in quakeml
        # Set pf_file path for test to use
        os.environ[common.ENV_VAR_PF_PATH] = os.path.join(os.path.dirname(__file__), os.pardir,
                                                          'test_data', 'webservice_fdsn.pf')
        url = f'{self.baseurl}/query?mindepth=0.1&maxdepth=1000000&minmagnitude=1&maxmagnitude=9'\
              '&limit=2&orderby=time&minlatitude=-90&maxlatitude=90&'\
              'minlongitude=-180&maxlongitude=180&nodata=404&starttime=123.4'
        resp = self.client.open(url, method='GET')
        self.assertEqual(resp.status_code, HTTPStatus.OK)
        # This query returns single evid as an OrderedDict in quakeml
        url = f'{self.baseurl}/query?mindepth=0.1&maxdepth=1000000&minmagnitude=4&maxmagnitude=9'\
              '&limit=2&orderby=time&minlatitude=-90&maxlatitude=90&'\
              'minlongitude=-180&maxlongitude=180&nodata=404&starttime=123.4'
        resp = self.client.open(url, method='GET')
        self.assertEqual(resp.status_code, HTTPStatus.OK)

        os.environ.pop(common.ENV_VAR_PF_PATH)

    def test_query_missing_req_arg(self):
    	# Missing starttime
        url = f'{self.baseurl}/query?mindepth=0.1&maxdepth=1000000&minmagnitude=4&maxmagnitude=9'\
              '&limit=1&orderby=time&minlatitude=-90&maxlatitude=90&'\
              'minlongitude=-180&maxlongitude=180&nodata=404'
        resp = self.client.open(url, method='GET')
        self.assertNotEqual(resp.status_code, HTTPStatus.BAD_REQUEST)

    def test_query_bad_arg_type(self):
        """Invalid maxmagnitude of 'a'"""
        url = f'{self.baseurl}/query?mindepth=1&maxdepth=1000000&minmagnitude=4&maxmagnitude=a'\
              '&limit=1&orderby=time&minlatitude=-90&maxlatitude=90&'\
              'minlongitude=-180&maxlongitude=180&nodata=404&starttime=123.4'
        resp = self.client.open(url, method='GET')
        self.assertEqual(resp.status_code, HTTPStatus.BAD_REQUEST)